<?php
/*
 * This file is part of GoTo Contact Center Webchat.
 *
 * GoTo Contact Center Webchat is free software: you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 * GoTo Contact Center Webchat is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License along with GoTo Contact Center Webchat.
 * If not, see <https://www.gnu.org/licenses/>.
 */
/**
 * GoTo Contact Center Webchat Admin Class
 *
 * @package     GoTo_Plugin
 * @subpackage
 * @copyright   Copyright (c) 2022, GoTo inc.
 * @license     https://www.gnu.org/licenses/gpl-3.0.txt
 * @since       0.1.0
 */

namespace GoToContactCenter;

if ( ! defined( 'ABSPATH' ) ) {
  exit;
}

/**
 * @property $plugin_name
 * @property $plugin_menu
 * @property $plugin_home_url
 * @property $plugin_version
 * @property $plugin_file
 * @property $plugin_slug
 * @property $plugin_dir
 * @property $plugin_url
 * @property $plugin_pref
 * @property $plugin_author_url
 */
class GoTo_Contact_Center_WebChat_Admin_Class {
  private $arg;

  public function __construct( $arg ) {
    $this->plugin_name        = $arg['plugin_name'];
    $this->plugin_menu        = $arg['plugin_menu'];
    $this->plugin_home_url    = $arg['plugin_home_url'];
    $this->plugin_version     = $arg['plugin_version'];
    $this->plugin_file        = $arg['plugin_file'];
    $this->plugin_slug        = $arg['plugin_slug'];
    $this->plugin_dir         = $arg['plugin_dir'];
    $this->plugin_url         = $arg['plugin_url'];
    $this->plugin_pref        = $arg['plugin_pref'];
    $this->plugin_author_url  = $arg['author_url'];

    add_filter( 'plugin_action_links', array( $this, 'action_links' ), 10, 2 );
    add_action( 'admin_menu', array( $this, 'add_admin_page' ) );
    add_filter( 'admin_footer_text', array( $this, 'admin_footer' ) );
    add_action( 'plugins_loaded', array( $this, 'plugin_check' ) );
  }

  public function action_links( $actions, $plugin_file ) {
    if ( strpos( $plugin_file, $this->plugin_file ) === false ) {
      return $actions;
    }

    $settings_link = '<a href="admin.php?page=' . $this->plugin_slug . '">' . __( 'Settings', 'goto-contact-center-webchat' ) . '</a>';
    array_unshift( $actions, $settings_link );

    return $actions;
  }

  public function add_admin_page() {
    if ( ! class_exists( 'GoTo_Contact_Center' ) ) {
      add_menu_page(
        $this->plugin_name . ' v' . $this->plugin_version,
        $this->plugin_menu,
        'manage_options',
        $this->plugin_slug,
        array( $this, 'plugin_page' ),
        'dashicons-admin-comments'
      );
    } else {
      add_submenu_page(
        'goto-contact-center-plugins',
        $this->plugin_name . ' v' . $this->plugin_version,
        $this->plugin_menu,
        'manage_options',
        $this->plugin_slug,
        array($this, 'plugin_page')
      );
    }
  }

  public function plugin_page() {
    global $typenow;
    $typenow = $this->plugin_slug;
    require_once plugin_dir_path( __FILE__ ) . 'partials/main.php';
    self::admin_style();
    self::admin_script();
  }

  public function admin_style() {
    wp_enqueue_style( $this->plugin_slug . '-style', $this->plugin_url . 'assets/css/style.css', false, $this->plugin_version );
    wp_enqueue_style( $this->plugin_slug . '-admin-style', $this->plugin_url . 'assets/css/admin.css', false, $this->plugin_version );
  }

  public function admin_script() {
    wp_enqueue_script( $this->plugin_slug . '-admin-script', $this->plugin_url . 'assets/js/admin.js', false, $this->plugin_version );
  }

  public function admin_footer( $footer_text ) {
    global $typenow;
    if ( $typenow == $this->plugin_slug ) {
      $rating_url = 'https://wordpress.org/support/plugin/goto-contact-center-webchat/reviews/?filter=5#new-post';
      $goto_footer_text = '
        <div style="display: flex; flex-direction: column; color: #3c434a; font-weight: 400; font-size: 0.625rem; line-height: 1rem">
            <span>' .
                      /*
                       * translators: %1$s is replaced with the name for the plugin (i.e. "GoTo's Contact Center Webchat"),
                       * %2$s is replaced with the version of the plugin (i.e. "0.1.0"),
                       * %3$s is replaced with the URL of the plugin (i.e. "https://wordpress.org/plugins/goto-contact-center-webchat/")
                       */
                      sprintf( __( 'Thank you for using <a href="%3$s" target="_blank">%1$s v%2$s</a>!', 'goto-contact-center-webchat' ), esc_html( $this->plugin_name ), esc_html( $this->plugin_version ), esc_url( $this->plugin_home_url ) ) . '&nbsp;|&nbsp;
            ' .
                /* translators: %s is replaced with "https://wordpress.org/support/plugin/goto-contact-center-webchat/reviews/?filter=5#new-post" */
                sprintf( __( 'Please <a href="%s" target="_blank">rate us on WordPress</a>', 'goto-contact-center-webchat' ), esc_url( $rating_url ) ) . '</span>
            <span>' . __( 'Copyright &nbsp;&copy;&nbsp;2022&nbsp;GoTo inc.', 'goto-contact-center-webchat' ) . '</span>
            <span>' .
                /* translators: %s is replaced with "https://www.gnu.org/licenses/gpl-3.0.html" */
                sprintf( __( 'Available under the <a href="%s">GNU General Public License 3.0 or later</a>', 'goto-contact-center-webchat' ), esc_url( 'https://www.gnu.org/licenses/gpl-3.0.html' ) ) . '</span>
        </div>';

      return $goto_footer_text . '<br />' . $footer_text;
    }

    return $footer_text;
  }
  public function plugin_check() {
    if ( isset( $_POST[ $this->plugin_slug . '_nonce' ] ) ) {
      if ( ! empty( $_POST ) && wp_verify_nonce( $_POST[ $this->plugin_slug . '_nonce' ], $this->plugin_slug . '_action' ) && current_user_can( 'manage_options' ) ) {
        self:: save_data();
      }
    }
  }

  public function save_data() {
    if ( isset( $_POST['submit'] ) ) {
      update_option($this->plugin_pref . '_activated', isset( $_POST['activated'] ) );
      if ( isset( $_POST['snippet'] ) ) {
        $allowed_html = array(
          'script' => array(
            'type' => array()
          )
        );
        update_option($this->plugin_pref . '_snippet', wp_kses( $_POST['snippet'], $allowed_html ) );
      }
    }
  }
}
