<?php
/*
 * This file is part of GoTo Contact Center Webchat.
 *
 * GoTo Contact Center Webchat is free software: you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 * GoTo Contact Center Webchat is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License along with GoTo Contact Center Webchat.
 * If not, see <https://www.gnu.org/licenses/>.
 */
/**
 * GoTo Contact Center Webchat Main plugin page
 *
 * @package     GoTo_Plugin
 * @subpackage
 * @copyright   Copyright (c) 2022, GoTo inc.
 * @license     https://www.gnu.org/licenses/gpl-3.0.txt
 * @since       0.1.0
 */

if ( ! defined( 'ABSPATH' ) ) {
  exit;
}

include_once( 'include-data.php' );
?>
<section id="goto-contact-center-webchat" class="goto-contact-center-webchat" aria-labelledby="goto-contact-center-webchat-header">
  <header>
    <h1 class="goto-contact-center-webchat__header" id="goto-contact-center-webchat-header">
      <?php echo esc_html( $this->plugin_name ); ?>
    </h1>
  </header>
  <form class="admin-form" action="admin.php?page=<?php echo esc_attr( $this->plugin_slug ); ?>" method="post">
    <input type="hidden" name="page" value="<?php echo esc_attr( $this->plugin_slug );?>" />
    <input type="hidden" name="plugdir" value="<?php echo esc_attr( $this->plugin_slug );?>" />
    <?php wp_nonce_field( $this->plugin_slug .'_action', $this->plugin_slug . '_nonce' ); ?>
    <section class="admin-form__field admin-form__field--checkbox" aria-labelledby="goto-contact-center-webchat-activation">
      <header>
        <h2 class="admin-form__field-header" id="goto-contact-center-webchat-activation">
          <?php _e( "GoTo's Contact Center Webchat feature activation", 'goto-contact-center-webchat' ); ?>
        </h2>
        <p class="admin-form__field-subtitle">
          <?php _e( "By activating GoTo's Contact Center Webchat, a chat bubble will be shown on all pages of your website", 'goto-contact-center-webchat' ); ?>
        </p>
      </header>
      <div class="admin-form__field-inner">
        <input class="admin-form__field-input admin-form__field-input--checkbox" id="goto-contact-center-webchat-activated" name="activated" type="checkbox" <?php echo $is_webchat_activated ? 'checked' : ''; ?>>
        <label class="admin-form__field-label" for="goto-contact-center-webchat-activated">
          <?php _e( "Activate GoTo's Contact Center Webchat for this site?", 'goto-contact-center-webchat' ); ?>
        </label>
      </div>
    </section>
    <section class="admin-form__field admin-form__field--textarea" aria-labelledby="goto-contact-center-webchat-snippet-title">
      <header>
        <h2 class="admin-form__field-header" id="goto-contact-center-webchat-snippet-title">
          <?php _e( "GoTo's Contact Center Webchat code snippet", 'goto-contact-center-webchat' ); ?>
        </h2>
        <p class="admin-form__field-subtitle">
          <?php _e( "The snippet is used to add the content to your site's pages", 'goto-contact-center-webchat' ); ?>
        </p>
      </header>
      <div class="admin-form__field-inner">
        <textarea class="admin-form__field-input admin-form__field-input--textarea" name="snippet" rows="10" cols="50" id="goto-contact-center-webchat-snippet" <?php echo ! $is_webchat_activated ? 'disabled' : 'required'; ?>><?php echo esc_textarea($webchat_snippet); ?></textarea>
        <label class="admin-form__field-label" for="goto-contact-center-webchat-snippet"><?php _e( 'Please insert the code snippet in the area above.', 'goto-contact-center-webchat' ); ?></label>
      </div>
    </section>
    <input type="submit" class="admin-form__submit" value="<?php _e( 'Save', 'goto-contact-center-webchat' ); ?>" name="submit">
  </form>
</section>
