<?php
/*
 * This file is part of GoTo Contact Center Webchat.
 *
 * GoTo Contact Center Webchat is free software: you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 * GoTo Contact Center Webchat is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License along with GoTo Contact Center Webchat.
 * If not, see <https://www.gnu.org/licenses/>.
 */
/**
 * Plugin Name:     GoTo Contact Center Webchat
 * Plugin URI:      https://wordpress.org/plugins/goto-contact-center-webchat/
 * Description:     The webchat plug-in for GoTo’s Contact Center provides a seamless integration for adding our webchat functionality to your website.
 * Version:         0.3.3
 * Author:          GoTo inc.
 * Author URI:      https://www.goto.com/
 * License:         GPL-3.0+
 * License URI:     http://www.gnu.org/licenses/gpl-3.0.html
 * Text Domain:     goto-contact-center-webchat
 */

namespace GoToContactCenter;

if ( ! defined('ABSPATH') ) {
  exit;
}



if ( ! class_exists('GoTo_Contact_Center_WebChat_Class') ) {
  final class GoTo_Contact_Center_WebChat_Class {
    private static $instance;

    const PREF = 'goto-contact-center-webchat';

    public static function instance() {
      if ( ! isset( self::$instance ) && ! ( self::$instance instanceof GoTo_Contact_Center_WebChat_Class ) ) {
        require_once  plugin_dir_path( __FILE__ ) . 'includes/version.php';
        $info = array(
          'plugin_name'     => __( "GoTo's Contact Center Webchat", 'goto-contact-center-webchat' ),
          'plugin_menu'     => __( "GoTo's Contact Center Webchat", 'goto-contact-center-webchat' ),
          'plugin_home_url' => 'https://wordpress.org/plugins/goto-contact-center-webchat/',
          'plugin_version'  => $version,
          'plugin_file'     => basename( __FILE__ ),
          'plugin_slug'     => dirname( plugin_basename( __FILE__ ) ),
          'plugin_dir'      => plugin_dir_path( __FILE__ ),
          'plugin_url'      => plugin_dir_url( __FILE__ ),
          'plugin_pref'     => self::PREF,
          'author_url'      => 'https://www.goto.com/'
        );

        self::$instance = new GoTo_Contact_Center_WebChat_Class;

        register_activation_hook( __FILE__, array( self::$instance, 'plugin_activate' ) );
        register_deactivation_hook( __FILE__, array( self::$instance, 'plugin_deactivate' ) );

        add_action( 'plugins_loaded', array( self::$instance, 'load_textdomain' ) );

        self::$instance->includes();

        self::$instance->admin = new GoTo_Contact_Center_WebChat_Admin_Class( $info );
        self::$instance->public = new GoTo_Contact_Center_WebChat_Public_Class( $info );
      }

      return self::$instance;
    }

    public function __clone() {
      // Cloning instances of the class is forbidden
      _doing_it_wrong( __FUNCTION__, __( 'Cloning an instance of the class is forbidden', 'goto-contact-center-webchat' ), '0.1.0');
    }

    public function __wakeup() {
      // Unserializing instances of the class is forbidden
      _doing_it_wrong( __FUNCTION__, __( 'Deserializing an instance of the class is forbidden', 'goto-contact-center-webchat' ), '0.1.0');
    }

    public function includes() {
      require_once plugin_dir_path( __FILE__ ) . 'admin/admin-class.php';
      require_once plugin_dir_path( __FILE__ ) . 'public/public-class.php';
    }

    public function plugin_activate() {
      require_once plugin_dir_path( __FILE__ ) . 'includes/activator.php';
    }

    public function plugin_deactivate() {
      require_once plugin_dir_path( __FILE__ ) . 'includes/deactivator.php';
    }

    public function load_textdomain() {
      load_plugin_textdomain( self::PREF, false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );
    }
  }
}

function goto_contact_center_webchat_plugin_run() {
  return GoTo_Contact_Center_WebChat_Class::instance();
}

goto_contact_center_webchat_plugin_run();
